/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright  2000-2002 The OGRE Team
Also see acknowledgements in Readme.html

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place - Suite 330, Boston, MA 02111-1307, USA, or go to
http://www.gnu.org/copyleft/lesser.txt.
-----------------------------------------------------------------------------
*/

#include <OgreVisibilityTerrainSceneManager.h>
#include <OgreVisibilityOctreeSceneManager.h>
//#include <OgreVisibilityDotSceneManager.h>
#include <OgreHeightmapTerrainPageSource.h>
#include <OgreRoot.h>

#include "VisibilityManager.h"
#include "StopAndWaitCullingManager.h"
#include "VisibilityEnvironment.h"

GtpVisibility::VisibilityEnvironment *visEnv;
GtpVisibility::VisibilityManager *visManager;

namespace Ogre {

// VisibilityDotSceneManager *cullingDotPlugin;
VisibilityOctreeSceneManager *cullingOctreePlugin;
VisibilityTerrainSceneManager *cullingTerrainPlugin;

HeightmapTerrainPageSource *heightmapTerrainPageSource;

//-----------------------------------------------------------------------
extern "C" void dllStartPlugin(void)
{
	visManager = new GtpVisibility::VisibilityManager(visEnv);
	// Create new scene manager
	//occlusionDotPlugin = new VisibilityDotSceneManager();
	cullingOctreePlugin = new VisibilityOctreeSceneManager(visManager);
	cullingTerrainPlugin = new VisibilityTerrainSceneManager(visManager);
	heightmapTerrainPageSource = new HeightmapTerrainPageSource();

	cullingTerrainPlugin->registerPageSource("Heightmap", heightmapTerrainPageSource);

	// Register
	//Root::getSingleton().setSceneManager( ST_GENERIC, occlusionDotPlugin );
	Root::getSingleton().setSceneManager( ST_GENERIC, cullingOctreePlugin );
	Root::getSingleton().setSceneManager( ST_EXTERIOR_CLOSE, cullingTerrainPlugin );
}
extern "C" void dllStopPlugin(void)
{
	delete heightmapTerrainPageSource;
    //delete occlusionDotPlugin;
	delete cullingOctreePlugin;
	delete cullingTerrainPlugin;
	delete visManager;
}

} //namespace Ogre
